#
#   This file is part of stov, written by Helmut Pozimski 2012-2015.
#
#   stov is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, version 2 of the License.
#
#   stov is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with stov.  If not, see <http://www.gnu.org/licenses/>.


# -*- coding: utf8 -*-

import os
import sys
import subprocess

from lib_stov import stov_exceptions


class video(object):
    def __init__(self, title, description, ytid, conf, downloaded, failcount=0,
                 id=0):
        self.__ID = id
        self.title = title
        self.description = description
        self.ytid = ytid
        self.__conf = conf
        self.downloaded = downloaded
        self.failcnt = int(failcount)

    def DownloadVideo(self, directory, itag_value, video_codec):
        """Downloads the video by calling youtube-dl as an external process"""
        targetdir = self.__conf.values["downloaddir"] + "/" + directory
        if os.access(targetdir, os.F_OK) is False:
            try:
                os.makedirs(targetdir, 0o750)
            except os.error:
                raise stov_exceptions.DirectoryCreationFailedException()

        os.chdir(targetdir)
        if self.downloaded == 0:
            try:
                if self.__conf.outputlevel == "default":
                    subprocess.check_call(["youtube-dl", "-f %s/%s"
                                          % (itag_value, video_codec), "-t",
                                           "http://www.youtube.com/watch?v=%s"
                                           % self.ytid],
                                          stderr=sys.stderr,
                                          stdout=open("/dev/null", "w"))
                elif self.__conf.outputlevel == "verbose":
                    subprocess.check_call(["youtube-dl", "-f %s/%s"
                                          % (itag_value, video_codec), "-t",
                                          "http://www.youtube.com/watch?v=%s"
                                           % self.ytid],
                                          stderr=sys.stderr, stdout=sys.stdout)
                elif self.__conf.outputlevel == "quiet":
                    subprocess.check_call(["youtube-dl", "-f %s/%s"
                                          % (itag_value, video_codec), "-t",
                                          "http://www.youtube.com/watch?v=%s"
                                          % self.ytid],
                                          stderr=open("/dev/null", "w"),
                                          stdout=open("/dev/null", "w"))
            except subprocess.CalledProcessError:
                self.failcnt = int(self.failcnt) + 1
                return False
            else:
                self.downloaded = 1
                return True

    def AssignDBID(self, id):
        self.__ID = id

    def GetID(self):
        return self.__ID
